"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.DescWriter = void 0;
const abstract_writer_1 = require("../common/abstract.writer");
const executor_1 = require("../executor");
const titles = [
    '字段名',
    '数据类型',
    '索引',
    '额外信息',
    '允许空',
    '默认值',
    '字段说明',
];
const keys = [
    'name',
    'type',
    'key',
    'extra',
    'isNullable',
    'defaultValue',
    'comment',
];
class DescWriter extends abstract_writer_1.AbstractWriter {
    write(db, table) {
        return __awaiter(this, void 0, void 0, function* () {
            const columns = yield new executor_1.ColumnsExecutor(db, table.name).exec();
            const text = [];
            // link
            text.push(...[`<a name="${table.name}"></a>`, '']);
            // title
            text.push(...[`* ${table.name}(${table.comment})[↑](#返回顶部)`, '']);
            // content
            text.push(['', ...titles, ''].join('|'));
            text.push(['', ...titles.map(() => ':---:'), ''].join('|'));
            columns.forEach((c) => {
                const values = keys.map((k) => c[k]);
                text.push(['', ...values, ''].join('|'));
            });
            // end new line
            text.push(...['', '']);
            this.stream.write(text.join('\n'));
        });
    }
}
exports.DescWriter = DescWriter;
